Class: Opentelemetry::Proto::Collector::Profiles::V1development::ProfilesService::Service
- Inherits:
-
Object
- Object
- Opentelemetry::Proto::Collector::Profiles::V1development::ProfilesService::Service
- Includes:
- GRPC::GenericService
- Defined in:
- lib/opentelemetry/proto/collector/profiles/v1development/profiles_service_services_pb.rb
Overview
Service that can be used to push profiles between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.